# Generated by Django 4.0.3 on 2022-03-09 11:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fittings', '0014_serverversion'),
    ]

    operations = [
        migrations.AddField(
            model_name='fitting',
            name='created',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='fitting',
            name='last_updated',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AlterField(
            model_name='doctrine',
            name='last_updated',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
    ]
