# Generated by Django 3.1.2 on 2021-02-21 01:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fittings', '0013_alter_doctrine_description'),
    ]

    operations = [
        migrations.CreateModel(
            name='ServerVersion',
            fields=[
                ('id', models.BigIntegerField(primary_key=True, serialize=False)),
            ],
            options={
                'verbose_name': 'ServerVersion',
                'default_permissions': (),
            },
        ),
    ]
