# Generated by Django 2.2.14 on 2020-08-15 20:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fittings', '0010_auto_20200718_2227'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='category',
            options={'default_permissions': (), 'verbose_name': 'Category', 'verbose_name_plural': 'Categories'},
        ),
        migrations.AlterField(
            model_name='fitting',
            name='description',
            field=models.TextField(max_length=500),
        ),
    ]
