# Generated by Django 2.2.14 on 2020-08-17 20:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fittings', '0012_typehistory'),
    ]

    operations = [
        migrations.AlterField(
            model_name='doctrine',
            name='description',
            field=models.TextField(max_length=1000),
        ),
    ]
