# Generated by Django 4.0.7 on 2022-09-29 21:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0007_evetype_description'),
        ('fittings', '0015_fitting_created_fitting_last_updated_and_more'),
    ]

    operations = [
        migrations.DeleteModel(
            name='DogmaAttribute',
        ),
        migrations.DeleteModel(
            name='DogmaEffect',
        ),
        migrations.RemoveField(
            model_name='itemgroup',
            name='category',
        ),
        migrations.DeleteModel(
            name='ServerVersion',
        ),
        migrations.RemoveField(
            model_name='type',
            name='group',
        ),
        migrations.DeleteModel(
            name='TypeHistory',
        ),
        migrations.AlterField(
            model_name='fitting',
            name='ship_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='eveuniverse.evetype'),
        ),
        migrations.AlterField(
            model_name='fittingitem',
            name='type_fk',
            field=models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='eveuniverse.evetype'),
        ),
        migrations.DeleteModel(
            name='ItemCategory',
        ),
        migrations.DeleteModel(
            name='ItemGroup',
        ),
        migrations.DeleteModel(
            name='Type',
        ),
    ]
